@@ -1049,7 +1049,7 @@ class WordToken(models.Model):
                 nformants = self.getNFormants()
                 outline['formants'] = [ {'time(s)':x['time(s)'],
                             'F1(Hz)':x['F1(Hz)'],
-                            'F2(Hz)':x['F2(Hz)'}
+                            'F2(Hz)':x['F2(Hz)']}
                             for p.get_formants(self.getDialogPath(),beg,end,nformants,ceiling)
                                 if x['F1(Hz)'] != '--undefined--' and x['F2(Hz)'] != '--undefined--']
             to_out = [ {'time(s)':x['time(s)'],
